==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiPage/WriNode.pm <==
#
# WiKicker
#
#  WriNode.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: WriNode.pm,v 1.3 2003/10/26 23:07:34 naney Exp $
#
#

package WiKicker::WikiPage::WriNode;

use strict;
use WiKicker::WikiPage::Acceptor;
use Carp;

use vars qw(@ISA);

@ISA = qw(WiKicker::WikiPage::Acceptor);

sub new {
  my ($class, $original, $reference, $wri_factory) = @_;

  croak "no wri_factory" unless defined $wri_factory;
  
  my $self = bless {}, $class;
  $self->original($original);
  $self->wri($wri_factory->create_wri($reference));

  return $self;
}

sub original {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{original} = $value;
  }

  return $self->{original};
}

sub wri {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{wri} = $value;
  }

  return $self->{wri};
}

sub to_string {
  return shift->original;
}

sub to_unarmor_string {
  return shift->to_string;
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiPage/WriNode.pm <==
#
# WiKicker
#
#  WriNode.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: WriNode.pm,v 1.5 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::WikiPage::WriNode;

use strict;
use WiKicker::WikiPage::Acceptor qw(:accept);
use Carp;

sub new {
  my ($class, $original, $reference, $wri_factory) = @_;

  croak 'no wri_factory' unless defined $wri_factory;

  my $self = bless {}, $class;
  $self->original($original);
  $self->wri($wri_factory->create_wri($reference));

  return $self;
}

sub original {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{original} = $value;
  }

  return $self->{original};
}

sub wri {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{wri} = $value;
  }

  return $self->{wri};
}

sub to_string {
  return shift->original;
}

sub to_unarmor_string {
  return shift->to_string;
}

1;
